@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2007 Participatory Culture Foundation
+# Copyright (C) 2005-2008 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
-# 
+#
 # In addition, as a special exception, the copyright holders give
 # permission to link the code of portions of this program with the OpenSSL
 # library.
@@ -36,18 +36,22 @@ def use_xine_hack_default():
     try:
         # Non-debian based system will throw an exception here
         f = open('/etc/debian_version')
-        if f.read().strip() == '4.0': # Debian etch
-            f.close()
+        osname = f.read().strip()
+        f.close()
+        # Debian Etch
+        if osname == '4.0':
+            return True
+
+        # Ubuntu Feisty et al is Debian-based but lists testing/unstable
+        # and similar things in /etc/debian_version, so we check /etc/issue.
+        f.close()
+        f = open('/etc/issue')
+        osname = f.read()
+        f.close()
+
+        if ((osname.find("Ubuntu") > -1) and 
+                ((osname.find("7.04")>-1) or (osname.find("7.10")>-1) or (osname.find("hardy")>-1))):
             return True
-        else:
-            # Ubuntu Feisty is Debian based but lists testing/unstable
-            # in /etc/debian_version, so we check /etc/issue
-            f.close()
-            f = open('/etc/issue')
-            osname = f.read()
-            if (osname.find("Ubuntu") > -1) and (osname.find("7.04")>-1):
-                f.close()
-                return True
     except:
         pass
     return False
@@ -74,7 +78,6 @@ from distutils.util import change_root
 from glob import glob
 from string import Template
 import distutils.command.build_py
-import distutils.command.build_py
 import distutils.command.install_data
 import os
 import pwd
@@ -102,26 +105,33 @@ while True:
         raise RuntimeError("Couldn't find Miro root directory")
     root_try = os.path.abspath(os.path.join(root_try, '..'))
 portable_dir = os.path.join(root_dir, 'portable')
+portable_frontend_dir = os.path.join(portable_dir, 'frontends')
+portable_html_frontend_dir = os.path.join(portable_frontend_dir, 'html')
 dl_daemon_dir = os.path.join(portable_dir, 'dl_daemon')
 test_dir = os.path.join(portable_dir, 'test')
-compiled_templates_dir = os.path.join(portable_dir, 'compiled_templates')
-compiled_templates_unittest_dir = os.path.join(compiled_templates_dir,'unittest')
 resource_dir = os.path.join(root_dir, 'resources')
 platform_dir = os.path.join(root_dir, 'platform', 'gtk-x11')
+platform_package_dir = os.path.join(platform_dir, 'platform')
+platform_html_frontend_dir = os.path.join(platform_package_dir, 'frontends',
+        'html')
 glade_dir = os.path.join(platform_dir, 'glade')
 xine_dir = os.path.join(platform_dir, 'xine')
-frontend_implementation_dir = os.path.join(platform_dir,
-        'frontend_implementation')
 debian_package_dir = os.path.join(platform_dir, 'debian_package')
 
-sys.path[0:0] = ['%s/platform/%s' % (root_dir, 'gtk-x11'), '%s/platform' % root_dir, '%s/portable' % root_dir]
+sys.path.insert(0, root_dir)
+# when we install the portable modules, they will be in the miro package, but
+# at this point, they are in a package named "portable", so let's hack it
+import portable
+sys.modules['miro'] = portable
+import platform
+sys.modules['miro'].platform = platform
 
-import template_compiler
-import setup_portable
+from miro.frontends.html import template_compiler
+from miro import setup_portable
 template_compiler.compileAllTemplates(root_dir)
 
 # little hack get the version from the current app.config.template
-import util
+from miro import util
 app_config = os.path.join(resource_dir, 'app.config.template')
 appVersion = util.readSimpleConfigFile(app_config)['appVersion']
 
@@ -231,7 +241,13 @@ try:
     packages = getCommandOutput("pkg-config --list-all")
 except RuntimeError, error:
     sys.exit("Package config error:\n%s" % (error,))
-if re.search("^xulrunner-xpcom", packages, re.MULTILINE):
+
+xulrunner19 = False
+if re.search("^libxul", packages, re.MULTILINE):
+    xulrunner19 = True
+    xpcom = 'libxul'
+    gtkmozembed = 'libxul'
+elif re.search("^xulrunner-xpcom", packages, re.MULTILINE):
     xpcom = 'xulrunner-xpcom'
     gtkmozembed = 'xulrunner-gtkmozembed'
 elif re.search("^mozilla-xpcom", packages, re.MULTILINE):
@@ -241,9 +257,8 @@ elif re.search("^firefox-xpcom", packages, re.MULTILINE):
     xpcom = 'firefox-xpcom'
     gtkmozembed = 'firefox-gtkmozembed'
 else:
-    sys.exit("Can't find xulrunner-xpcom, mozilla-xpcom or firefox-xpcom")
+    sys.exit("Can't find libxul, xulrunner-xpcom, mozilla-xpcom or firefox-xpcom")
 
-# do this so that it doesn't execute when doing python setup.py clean
 if not "clean" in sys.argv:
     # build a miro script that wraps the miro.real script with an LD_LIBRARY_PATH
     # environment variable to pick up the xpcom we decided to use.
@@ -252,13 +267,16 @@ if not "clean" in sys.argv:
         # pluck off the last \n
         fflib = fflib[:-1]
         f = open(os.path.join(platform_dir, "miro"), "w")
-        f.write('#!/bin/sh\necho %s\nLD_LIBRARY_PATH=%s ADDON_PATH=/tmp/empty miro.real "$@"\n' % (fflib, fflib))
+        if fflib:
+            f.write("#!/bin/sh\nLD_LIBRARY_PATH=%s miro.real \"$@\"\n" % fflib)
+        else:
+            f.write("#!/bin/sh\nmiro.real \"$@\"\n")
         f.close()
     except RuntimeError, error:
         sys.exit("Package config error:\n%s" % (error,))
 
 mozilla_browser_options = parsePkgConfig("pkg-config" , 
-        "gtk+-2.0 glib-2.0 pygtk-2.0 %s %s" % (gtkmozembed, xpcom))
+        "gtk+-2.0 glib-2.0 pygtk-2.0 --define-variable=includetype=unstable %s %s" % (gtkmozembed, xpcom))
 mozilla_lib_path = parsePkgConfig('pkg-config', 
         '%s' % gtkmozembed)['library_dirs']
 # Find the base mozilla directory, and add the subdirs we need.
@@ -275,12 +293,20 @@ for dir in xpcom_includes['include_dirs']:
         # base include directory
         mozIncludeBase = dir
         break
+
+# xulrunner 1.9 has a different directory structure where all the headers are
+# in the same directory.
 if mozIncludeBase is None:
-    raise ValueError("Can't find mozilla include base directory")
-for subdir in ['dom', 'gfx', 'widget', 'commandhandler', 'uriloader',
-            'webbrwsr', 'necko', 'windowwatcher']:
-    path = os.path.join(mozIncludeBase, subdir)
-    mozilla_browser_options['include_dirs'].append(path)
+    if xulrunner19 == True:
+        mozilla_browser_options['include_dirs'].append(dir)
+    else:
+        raise ValueError("Can't find mozilla include base directory")
+
+else:
+    for subdir in ['dom', 'gfx', 'widget', 'commandhandler', 'uriloader',
+                   'webbrwsr', 'necko', 'windowwatcher']:
+        path = os.path.join(mozIncludeBase, subdir)
+        mozilla_browser_options['include_dirs'].append(path)
 
 
 nsI = True
@@ -295,20 +321,25 @@ for dir in mozilla_browser_options['include_dirs']:
 if nsI:
     mozilla_browser_options['extra_compile_args'].append('-DNS_I_SERVICE_MANAGER_UTILS=1')
 
-mozilla_browser_ext = Extension("miro.MozillaBrowser",
-        [ os.path.join(frontend_implementation_dir,'MozillaBrowser.pyx'),
-          os.path.join(frontend_implementation_dir,'MozillaBrowserXPCOM.cc'),
-          os.path.join(frontend_implementation_dir,'HttpObserver.cc'),
-          os.path.join(frontend_implementation_dir,'PromptService.cc'),
-          os.path.join(frontend_implementation_dir,'DragAndDrop.cc'),
-          os.path.join(frontend_implementation_dir,'XPCOMUtil.cc'),
+# FIXME - WBG
+# do a xulrunner 1.9 check here and if not, then define PCF_USING_XULRUNNER19
+if xulrunner19:
+    mozilla_browser_options['extra_compile_args'].append('-DPCF_USING_XULRUNNER19=1')
+
+mozilla_browser_ext = Extension("miro.platform.MozillaBrowser",
+        [ os.path.join(platform_html_frontend_dir,'MozillaBrowser.pyx'),
+          os.path.join(platform_html_frontend_dir,'MozillaBrowserXPCOM.cc'),
+          os.path.join(platform_html_frontend_dir,'HttpObserver.cc'),
+          os.path.join(platform_html_frontend_dir,'PromptService.cc'),
+          os.path.join(platform_html_frontend_dir,'DragAndDrop.cc'),
+          os.path.join(platform_html_frontend_dir,'XPCOMUtil.cc'),
         ],
         runtime_library_dirs=mozilla_lib_path,
         **mozilla_browser_options)
 #### Xlib Extension ####
 xlib_ext = \
-    Extension("miro.xlibhelper", 
-        [ os.path.join(frontend_implementation_dir,'xlibhelper.pyx') ],
+    Extension("miro.platform.xlibhelper", 
+        [ os.path.join(platform_html_frontend_dir,'xlibhelper.pyx') ],
         library_dirs = ['/usr/X11R6/lib'],
         libraries = ['X11'],
     )
@@ -351,7 +382,6 @@ for dir in ('templates', 'css', 'images', 'html', 'testdata', os.path.join('temp
     data_files.append((dest_dir, listfiles(source_dir)))
 # add the desktop file, icons, mime data, and man page.
 
-# do this so that it doesn't execute when doing python setup.py clean
 if not "clean" in sys.argv:
     rv = os.system ("gcc %s -o %s `pkg-config --libs --cflags gdk-pixbuf-2.0 glib-2.0 libxine`" % (os.path.join(platform_dir, "xine/xine_extractor.c"), os.path.join(platform_dir, "xine/xine_extractor")))
 
@@ -436,37 +466,9 @@ class build_py (distutils.command.build_py.build_py):
             expanded = template.substitute(**conf)
             write_file(path, expanded)
         
-    def find_miro_modules(self):
-        """Returns a list of modules to go in the miro directory.  Each
-        item has the form (package, module, path).  The trick here is merging
-        the contents of the platform/gtk-x11 and portable directories.
-        """
-        self.expand_templates()
-        files = glob(os.path.join(portable_dir, '*.py'))
-        files.extend(glob(os.path.join(platform_dir, '*.py')))
-        rv = []
-        for f in files:
-            if os.path.samefile(f, __file__):
-                continue
-            module = os.path.splitext(os.path.basename(f))[0]
-            rv.append(('miro', module, f))
-        return rv
-
-    def find_all_modules (self):
+    def run (self):
         """Extend build_py's module list to include the miro modules."""
-        modules = distutils.command.build_py.build_py.find_all_modules(self)
-        modules.extend(self.find_miro_modules())
-        return modules
-
-    def run(self):
-        """Do the build work.  In addition to the default implementation, we
-        also build the miro package from the platform and portable code
-        and install the resources as package data.  
-        """
-
-        for (package, module, module_file) in self.find_miro_modules():
-            assert package == 'miro'
-            self.build_module(module, module_file, package)
+        self.expand_templates()
         return distutils.command.build_py.build_py.run(self)
 
 #### bdist_deb builds the miro debian package ####
@@ -613,19 +615,24 @@ setup(name='miro',
         #        [os.path.join(portable_dir, 'template.pyx')]),
     ],
     packages = [
-        'miro.frontend_implementation',
+        'miro',
         'miro.dl_daemon',
         'miro.test',
-        'miro.compiled_templates',
-        'miro.compiled_templates.unittest',
         'miro.dl_daemon.private',
+        'miro.frontends',
+        'miro.frontends.cli',
+        'miro.frontends.html',
+        'miro.frontends.html.compiled_templates',
+        'miro.frontends.html.compiled_templates.unittest',
+        'miro.platform',
+        'miro.platform.frontends',
+        'miro.platform.frontends.html',
+        'miro.platform.renderers',
     ],
     package_dir = {
-        'miro.frontend_implementation' : frontend_implementation_dir,
-        'miro.dl_daemon' : dl_daemon_dir,
+        'miro': portable_dir,
         'miro.test' : test_dir,
-        'miro.compiled_templates' : compiled_templates_dir,
-        'miro.compiled_templates.unittest' : compiled_templates_unittest_dir,
+        'miro.platform': platform_package_dir,
     },
     cmdclass = {
         'build_ext': build_ext, 
