@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2007 Participatory Culture Foundation
+# Copyright (C) 2005-2008 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -86,27 +86,21 @@ STUB_PATH = os.path.join(BINARY_KIT_ROOT, 'stub')
 # py2exe.
 COMPILER_RUNTIMES = [
     # Visual C++ 7.1 C runtime library (required by Python, if nothing else)
-    os.path.join(BINARY_KIT_ROOT, 'vc71redist', 'msvcr71.dll'),
+    #
+    # This should get automatically detected now
+    #os.path.join(BINARY_KIT_ROOT, 'vc71redist', 'msvcr71.dll'),
     # Visual C++ 7.1 C++ runtime library (required by Boost-Python)
     os.path.join(BINARY_KIT_ROOT, 'vc71redist', 'msvcp71.dll'),
     ]
 
-# Python runtime DLL to distribute with the application. Usually, the
-# Python installer drops it in c:\windows\system32.
-if sys.version.startswith("2.4"):
-    PYTHON_RUNTIMES = [
-        "C:\\windows\\system32\\python24.dll",
-        ]
-else: # We must be using Python 2.5
-    PYTHON_RUNTIMES = [
-        "C:\\windows\\system32\\python25.dll",
-        ]
-
 # Path to the Mozilla "xulrunner" distribution. We include a build in
 # the Binary Kit to save you a minute or two, but if you want to be
 # more up-to-date, nightlies are available from Mozilla at:
 #  http://ftp.mozilla.org/pub/mozilla.org/xulrunner/nightly/
-XULRUNNER_DIR = os.path.join(BINARY_KIT_ROOT, "xulrunner")
+for xulloc in ["xulrunner19","xulrunner18","xulrunner"]:
+    if os.path.exists(os.path.join(BINARY_KIT_ROOT, xulloc)):
+        XULRUNNER_DIR = os.path.join(BINARY_KIT_ROOT, xulloc)
+        break
 
 # Path to "xpidl" and "xpt_link", Mozilla tools to compile IDL
 # interface files to type libraries. Get by building Mozilla or
@@ -117,7 +111,10 @@ IDL_TOOLS_PATH = os.path.join(BINARY_KIT_ROOT, "idltools")
 # Path to the IDL include directory, containing declarations of the
 # basic Mozilla interfaces. Get this out of the XUL SDK when it's
 # released, or the GRE SDK for now.
-IDL_INCLUDE_PATH = os.path.join(BINARY_KIT_ROOT, "idlinclude")
+for idlloc in ["idlinclude19","idlinclude18","idlinclude"]:
+    if os.path.exists(os.path.join(BINARY_KIT_ROOT, idlloc)):
+        IDL_INCLUDE_PATH = os.path.join(BINARY_KIT_ROOT, idlloc)
+        break
 
 # Path to a separate build of PyXPCOM, the glue that binds Python to
 # Mozilla. This is now optional, since it's not too difficult to build
@@ -172,22 +169,23 @@ platform = 'windows-xul'
 
 # Find the top of the source tree and set search path
 root = os.path.join(os.path.dirname(os.path.abspath(sys.argv[0])), '..', '..')
+root = os.path.normpath(os.path.abspath(root))
 platform_dir = os.path.join(root, 'platform', 'windows-xul')
 portable_dir = os.path.join(root, 'portable')
-sys.path[0:0] = [
-    platform_dir,
-    portable_dir,
-]
-root = os.path.normpath(root)
+sys.path.insert(0, root)
+# when we install the portable modules, they will be in the miro package, but
+# at this point, they are in a package named "portable", so let's hack it
+import portable
+sys.modules['miro'] = portable
 
 #### The database extension ####
-database_ext = Extension("database", 
+database_ext = Extension("miro.database", 
         sources=[os.path.join(root, 'portable', 'database.pyx')])
 
 #### The fasttypes extension ####
 
 fasttypes_ext = \
-    Extension("fasttypes", 
+    Extension("miro.fasttypes", 
         sources = [os.path.join(root, 'portable', 'fasttypes.cpp')],
         library_dirs = [BOOST_LIB_PATH],
         include_dirs = [BOOST_INCLUDE_PATH]
@@ -212,9 +210,8 @@ def fetchCpp():
 libtorrent_sources=list(fetchCpp())
 libtorrent_sources.remove(os.path.join(portable_dir, 'libtorrent\\src\\file.cpp'))
 
-print [ BOOST_LIB_PATH, OPENSSL_LIB_PATH, ZLIB_LIB_PATH]
 libtorrent_ext = Extension(
-        "libtorrent", 
+        "miro.libtorrent", 
         include_dirs = [
             os.path.join(portable_dir, 'libtorrent', 'include'),
             os.path.join(portable_dir, 'libtorrent', 'include', 'libtorrent'),
@@ -249,11 +246,11 @@ ext_modules = [
 
     # Pyrex sources.
     #Extension("vlc", [os.path.join(root, 'platform',platform, 'vlc.pyx')],libraries=["simplevlc"]),
-    Extension("sorts", [os.path.join(root, 'portable', 'sorts.pyx')]),
+    Extension("miro.sorts", [os.path.join(root, 'portable', 'sorts.pyx')]),
     #Extension("template", [os.path.join(root, 'portable', 'template.pyx')]),
 ]
 
-import template_compiler
+from miro.frontends.html import template_compiler
 
 def fillTemplate(templatepath, outpath, xml=False, **vars):
     s = open(templatepath, 'rt').read()
@@ -345,13 +342,16 @@ class bdist_xul_dumb(Command):
         # Find our 'resources' tree (NEEDS)
         self.appResources = os.path.join(root, 'resources')
         # Find our various data bits (NEEDS)
-        self.xulTemplateDir = os.path.join(root, 'platform', platform,
-                                           'xul')
+        self.xulTemplateDir = os.path.join(root, 'platform', platform, 'xul')
+        self.xul_dist_dir = os.path.join(self.dist_dir, 'xulrunner', 'python')
 
     def run(self):
-        self.buildMovieDataUtil()
         self.makeAppConfig()
+        # It seems that buildMovieDataUtil changes the Include env variable 
+        # which messes up makeStubEXE for me.  So we need to make sure to call
+        # makeStubEXE() first (BDK)
         self.makeStubEXE()
+        self.buildMovieDataUtil()
         self.setTemplateVariable("pyxpcomIsEmbedded", "true")
         self.fillTemplates()                  
 
@@ -378,11 +378,11 @@ class bdist_xul_dumb(Command):
         # Add application Python modules to search path
         # NEEDS: should compile all Python files, and add the *build*
         # directories to the path.
-        packagePaths.extend([
-                os.path.join(root, 'platform', platform),
-                os.path.join(root, 'platform'),
-                os.path.join(root, 'portable'),
-                ])
+        #packagePaths.extend([
+                #os.path.join(root, 'platform', platform),
+                #os.path.join(root, 'platform'),
+                #os.path.join(root, 'portable'),
+                #])
 
         # Add PyXPCOM's runtime scripts directory to the search path,
         # and call out a list of top-level modules (those imported by
@@ -398,28 +398,22 @@ class bdist_xul_dumb(Command):
             packagePaths.extend([
                 os.path.join(XULRUNNER_DIR, "python"),
                 ])
+
         moduleIncludes = [# Public to Python code
                            "xpcom",
                            "xpcom.components",
                            "xpcom.file",
-                           "xpcom.register",
+                           #"xpcom.register",
                            # Used by C++ XPConnect bridge to Mozilla
                            "xpcom._xpcom",
                            "xpcom.client",
                            "xpcom.server",
                            # This manages to escape but looks important (?)
                            "xpcom.server.enumerator",
-                           # slips through because it's only included by
-                           # platform code
-                           "keyboard", 
+                           # The Python initialization script.
+                           "site",
                            ]
 
-        # Add other stuff that is necessary to get a functional Python
-        # environment.
-        moduleIncludes.extend([
-                # The Python initialization script.
-                "site",
-                ])
         packageIncludes = [
             # Make sure all the codecs we need make it in. Otherwise the
             # dependency scanner isn't clever enough to find them.
@@ -431,18 +425,27 @@ class bdist_xul_dumb(Command):
         # NEEDS: should bootstrap dependency scan from *.py in component
         # directory..
         log.info("computing module dependencies")
-        wellConnectedFile = os.path.join(root, 'portable', 'app.py')
+        wellConnectedFile = os.path.join(self.xulTemplateDir, 'components',
+                'pybridge.py')
         scriptIncludes = [wellConnectedFile]
         manifest = self.computePythonManifest(scripts = scriptIncludes,
                                               includes = moduleIncludes,
                                               packages = packageIncludes,
                                               path = packagePaths)
 
-        # Hack to add support for sqlite3 until it makes it into py2exe -NN
+        dlls = []
         for (source, dest) in manifest:
-            if source.endswith('_sqlite3.pyd'):
-                manifest.append((os.path.join(os.path.dirname(source), "sqlite3.dll"),"sqlite3.dll"))
-                break
+            if source.endswith(".pyd"):
+                dlls.append(source)
+ 
+        (alldlls,warninging, other_deps) = self.find_dependend_dlls(dlls,"",("xpcom.dll","pyxpcom.dll"))
+        for dll in alldlls:
+            manifest.append((dll,os.path.basename(dll)))
+
+        # Hack to get msvcp71.dll in there. py2exe.build_exe.isSystemDll()
+        # recognizes msvcr71.dll as non-system but misses the C++ runtime.
+        for dll in COMPILER_RUNTIMES:
+            manifest.append((dll,os.path.basename(dll)))
 
         #print '\n'.join(["%s -> %s" % (source, dest) \
         #                 for (source, dest) in manifest])
@@ -484,10 +487,14 @@ class bdist_xul_dumb(Command):
         # Copy the files indicated in the manifest to create a complete
         # application package.
         log.info("creating application image")
-        imageRoot = os.path.join(self.dist_dir, 'xulrunner', 'python')
+        miro_source = os.path.join(build.build_lib, 'miro')
+        miro_dest = os.path.join(self.xul_dist_dir, 'miro')
+        shutil.copytree(miro_source, miro_dest)
         dirsCreated = set()
         for (source, dest) in manifest:
-            dest = os.path.join(imageRoot, dest)
+            if dest.startswith('miro'):
+                continue
+            dest = os.path.join(self.xul_dist_dir, dest)
             destDir = os.path.dirname(dest)
             if destDir not in dirsCreated:
                 if not os.access(destDir, os.F_OK):
@@ -495,49 +502,6 @@ class bdist_xul_dumb(Command):
                 dirsCreated.add(destDir)
             shutil.copy2(source, dest)
 
-        # Copy required DLLs.
-        # NEEDS: shared library dependency scan, starting with pyloader
-        # and any python extensions, instead of this static list
-        log.info("copying DLL dependencies")
-        # NEEDS: Some Microsoft documentation says that the DLL search
-        # order is (1) the directory containing the "executable module
-        # for the current process", (2) the current directory, (3)
-        # GetSystemDirectory(), (4) GetWindowsDirectory(), and finally
-        # (5) PATH. That would suggest that we could put the DLLs in
-        # the same directory as xulrunner.exe and everything would be
-        # grand. In fact, everything is grand only if the DLLs are on
-        # PATH or in the current directory.
-        #
-        # Elsewhere, I read that the search order changed recently
-        # (SP1?): "No longer is the current directory searched first
-        # when loading DLLs! ... The default behavior now is to look
-        # in all the system locations first, then the current
-        # directory, and finally any user-defined paths. This will
-        # have an impact on your code if you install a DLL in the
-        # application's directory because Windows Server 2003 no
-        # longer loads the 'local' DLL if a DLL of the same name is in
-        # the system directory." (Google for "Development Impacts of
-        # Security Changes in Windows Server 2003.) The purpose of the
-        # change was to eliminate an opportunity for an attacker to
-        # put trojaned versions of the system DLLs into an application
-        # directory. The article is mum on this concept of searching
-        # the "executable module for the current directory."
-        #
-        # For now, let's dump the DLLs in the same directory as
-        # xulrunner-stub.exe (aka dtv.exe) and require that the
-        # current directory be the directory that contains the binary
-        # when it is run. This can easily be accomplished with a
-        # Windows shortcut, which is the way end-users will be
-        # starting the program. [And in fact the new Democracy.exe
-        # launcher now ensures that xulrunner is already run with the
-        # current directory set appropriately.]
-#        dllDistDir = self.xulrunnerOut
-        dllDistDir = self.dist_dir
-        allRuntimes = (PYTHON_RUNTIMES + BOOST_RUNTIMES + COMPILER_RUNTIMES +
-                ZLIB_RUNTIMES)
-        for runtime in allRuntimes:
-            shutil.copy2(runtime, dllDistDir)
-
         # Copy in our application's resources.
         log.info("copying application resources")
         copyTreeExceptSvn(self.appResources,
@@ -546,7 +510,11 @@ class bdist_xul_dumb(Command):
         self.copyMovieDataUtil()
         shutil.copy2("Democracy.nsi", self.dist_dir)
         shutil.copy2("Miro.ico", os.path.join(self.dist_dir, "%s.ico" % (self.getTemplateVariable('shortAppName'))))
-        shutil.copy2("iHeartMiro-installer-page.ini", self.dist_dir)
+        shutil.copy2("MiroBar-installer-page.ini", self.dist_dir)
+        shutil.copy2("askBarSetup-4.1.0.2.exe", self.dist_dir)
+        shutil.copy2("ask_toolbar.bmp", self.dist_dir)
+        shutil.copy2("miro-installer.ico", self.dist_dir)
+        shutil.copy2("miro-install-image.bmp", self.dist_dir)
 #        copyTreeExceptSvn(os.path.join(platform_dir, "iHeartMiro"), os.path.join(self.dist_dir, "iHeartMiro"))
 
 
@@ -571,7 +539,8 @@ class bdist_xul_dumb(Command):
         os.remove(os.path.join(self.xulrunnerOut, "xulrunner-stub.exe"))
         
         # Finally, build the download daemon
-        self.buildDownloadDaemon(self.dist_dir)
+        self.buildDownloadDaemon()
+        self.moveDLLs()
         
     def computePythonManifest(self, path=None, scripts=[], packages=[],
                               includes=[], excludes=[]):
@@ -653,10 +622,76 @@ class bdist_xul_dumb(Command):
 
         return manifest
 
-    def buildDownloadDaemon(self, baseDir):
+    def find_dependend_dlls(self, dlls, pypath, dll_excludes):
+        # based off of function in py2exe 0.6.6 by jimmy@retzlaff.com
+        # licensed under MIT/X11 license        
+        from py2exe import py2exe_util
+        from py2exe.build_exe import bin_depends
+
+# Uncomment this and the line at the bottom of the function to get
+# py2exe to know that msvcp71.dll is not a system dll --NN
+#
+#         import py2exe
+#         from py2exe.build_exe import isSystemDLL
+#         origIsSystemDLL = isSystemDLL
+#         def newIsSystemDLL(pathname):
+#             if os.path.basename(pathname).lower() in ("msvcr71.dll", "msvcr71d.dll", "msvcp71.dll", "msvcp71d.dll"):
+#                 return 0
+#             else:
+#                 return origIsSystemDLL(pathname)
+#         py2exe.build_exe.isSystemDLL = newIsSystemDLL
+
+        sysdir = py2exe_util.get_sysdir()
+        windir = py2exe_util.get_windir()
+        # This is the tail of the path windows uses when looking for dlls
+        # XXX On Windows NT, the SYSTEM directory is also searched
+        exedir = os.path.dirname(sys.executable)
+        syspath = os.environ['PATH']
+        loadpath = ';'.join([exedir, sysdir, windir, syspath])
+
+        # Found by Duncan Booth:
+        # It may be possible that bin_depends needs extension modules,
+        # so the loadpath must be extended by our python path.
+        loadpath = loadpath + ';' + ';'.join(pypath)
+
+        # We use Python.exe to track the dependencies of our run stubs ...
+        images = dlls
+
+        log.info("Resolving binary dependencies:")
+
+        # we add python.exe (aka sys.executable) to the list of images
+        # to scan for dependencies, but remove it later again from the
+        # results list.  In this way pythonXY.dll is collected, and
+        # also the libraries it depends on.
+        alldlls, warnings, other_depends = \
+                 bin_depends(loadpath, images + [sys.executable], dll_excludes)
+        alldlls.remove(sys.executable)
+        for dll in alldlls:
+            log.info("  %s" % dll)
+
+        # uncomment this if you override py2exe's isSystemDLL above
+        #py2exe.build_exe.isSystemDLL = origIsSystemDLL
+        
+        return alldlls, warnings, other_depends
+    # find_dependend_dlls()
+
+
+    def buildDownloadDaemon(self):
         print "building download daemon"
         os.system("%s setup_daemon.py py2exe --dist-dir %s" % 
-                (PYTHON_BINARY, self.dist_dir))
+                (PYTHON_BINARY, self.xul_dist_dir))
+
+    def moveDLLs(self):
+        print "moving all DLL files to %s" % self.dist_dir
+        for dll in glob(os.path.join(self.xul_dist_dir, '*.dll')):
+            basename = os.path.basename(dll)
+            # The Python DLL needs to be in the same directory as the
+            # main xulrunner binary for XULRunner to find it, but it
+            # also needs to be in the python directory for the
+            # downloader to find it. See #9648
+            dest = os.path.join(self.dist_dir, basename)
+            if not os.path.exists(dest):
+                shutil.copy(dll, dest)
 
     def buildMovieDataUtil(self):
         print "building movie data utility"
@@ -689,11 +724,11 @@ class bdist_xul_dumb(Command):
     # app bundle plugin directory, which is the way you're "supposed"
     # to do it so your app is cleanly separated from xulrunner.
     def copyVLCPluginFiles(self, baseDir, xulrunnerDir):
-        destDir = os.path.join(xulrunnerDir, 'plugins')
+        destDir = os.path.join(baseDir, 'plugins')
         if not os.access(destDir, os.F_OK):
             os.mkdir(destDir)
 
-        pluginFiles = ['libvlc.dll', 'npvlc.dll', 'vlcintf.xpt']
+        pluginFiles = ['libvlc.dll', 'npvlc.dll']
         for f in pluginFiles:
             shutil.copy2(os.path.join(VLC_MOZ_PLUGIN_DIR, f), destDir)
 
@@ -758,7 +793,7 @@ class bdist_xul_dumb(Command):
     # NEEDS: Very sloppy. The new file is just dropped in the source tree
     # next to the old one. This also initializes self.templateVars.
     def makeAppConfig(self):
-        import util
+        from miro import util
         revision = util.queryRevision(root)
         if revision is None:
             revision = "unknown"
@@ -774,6 +809,7 @@ class bdist_xul_dumb(Command):
         self.templateVars = util.readSimpleConfigFile(path)
 
     def makeStubEXE(self):
+         print "building EXE stub"
          version = self.getTemplateVariable('appVersion')
          versionComponents = version.split('-')[0].split('.')
          # FIXME - should this be < 4 or <= 4 ?
@@ -791,7 +827,7 @@ class bdist_xul_dumb(Command):
          os.chdir(stubDir)
          rv = os.system("rc Democracy.rc")
          if rv == 0:
-             cmd = 'cl  /DXULRUNNER_BIN="\\"%s.exe\\"" Democracy.cpp /link shell32.lib /subsystem:windows /machine:x86 Democracy.RES /out:"%s.exe"' % (self.getTemplateVariable('shortAppName'),self.getTemplateVariable('shortAppName'))
+             cmd = 'cl  /DXULRUNNER_BIN="\\"%s.exe\\"" Democracy.cpp /link shell32.lib Advapi32.lib /subsystem:windows /machine:x86 Democracy.RES /out:"%s.exe"' % (self.getTemplateVariable('shortAppName'),self.getTemplateVariable('shortAppName'))
              #print cmd
              rv = os.system(cmd)
          os.chdir(olddir)
@@ -866,8 +902,10 @@ class clean(Command):
             pass
         print "Removing old compiled templates..."
         try:
-            for filename in os.listdir(os.path.join("..","..","portable","compiled_templates")):
-                filename = os.path.join("..","..","portable","compiled_templates",filename)
+            template_dir = os.path.join("..","..","portable", "frontends",
+                    "html", "compiled_templates")
+            for filename in os.listdir(template_dir):
+                filename = os.path.join(template_dir, filename)
                 if os.path.isdir(filename):
                     shutil.rmtree(filename)
                 else:
@@ -897,7 +935,6 @@ class bdist_xul (bdist_xul_dumb):
 
         nsisVars['CONFIG_EXECUTABLE'] = "%s.exe" % (self.getTemplateVariable('shortAppName'))
         nsisVars['CONFIG_MOVIE_DATA_EXECUTABLE'] = "%s_MovieData.exe" % (self.getTemplateVariable('shortAppName'))
-        nsisVars['CONFIG_DL_EXECUTABLE'] = "%s_Downloader.exe" % (self.getTemplateVariable('shortAppName'))
         nsisVars['CONFIG_ICON'] = "%s.ico" % (self.getTemplateVariable('shortAppName'))
         nsisVars['CONFIG_PROG_ID'] = self.getTemplateVariable('longAppName').replace(" ",".")+".1"
 
@@ -936,14 +973,7 @@ class bdist_xul (bdist_xul_dumb):
         self.zipfile = zip.ZipFile(os.path.join (self.dist_dir, "%s-Contents-%s.zip" % (self.getTemplateVariable('shortAppName'),self.getTemplateVariable('appVersion'),)), 'w', zip.ZIP_DEFLATED)
         self.addFile (nsisVars['CONFIG_EXECUTABLE'])
         self.addFile (nsisVars['CONFIG_ICON'])
-        self.addFile (nsisVars['CONFIG_DL_EXECUTABLE'])
         self.addFile ("application.ini")
-        self.addFile ("msvcp71.dll")
-        self.addFile ("msvcr71.dll")
-        if sys.version.startswith("2.4"):
-            self.addFile ("python24.dll")
-        else: # We must be using Python 2.5
-            self.addFile ("python25.dll")
 
         self.addDirectory ("chrome")
         self.addDirectory ("components")
@@ -999,6 +1029,21 @@ def copyTreeExceptSvn(src, dest, filterOut=None):
 if __name__ == "__main__":
     setup(
         ext_modules = ext_modules,
+        packages = [
+            'miro',
+            'miro.dl_daemon',
+            'miro.dl_daemon.private',
+            'miro.frontends',
+            'miro.frontends.html',
+            'miro.frontends.html.compiled_templates',
+            'miro.platform',
+            'miro.platform.frontends',
+            'miro.platform.frontends.html',
+        ],
+        package_dir = {
+            'miro': portable_dir,
+            'miro.platform': os.path.join(platform_dir, 'platform'),
+        },
         cmdclass = {
             'build_ext': build_ext,
             'runxul': runxul,
