@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2007 Participatory Culture Foundation
+# Copyright (C) 2005-2008 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,13 +26,13 @@
 # this exception statement from your version. If you delete this exception
 # statement from all source files in the program, then also delete it here.
 
-import filters
-import views
-import config
-import prefs
-import eventloop
-import httpclient
-from clock import clock
+from miro import filters
+from miro import views
+from miro import config
+from miro import prefs
+from miro import eventloop
+from miro import httpclient
+from miro.clock import clock
 from datetime import datetime
 from fasttypes import SortedList
 
