@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2007 Participatory Culture Foundation
+# Copyright (C) 2005-2008 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -32,13 +32,12 @@ NOTE: For really old versions (before the schema.py module, see
 olddatabaseupgrade.py)
 """
 
-import schema
-import util
+from miro import schema
+from miro import util
 import types
 from urlparse import urlparse
-from storedatabase import SavableObject
-import config
-import prefs
+from miro import config
+from miro import prefs
 
 class DatabaseTooNewError(Exception):
     """Error that we raise when we see a database that is newer than the
@@ -167,7 +166,7 @@ def upgrade11(objectList):
     return set()
 
 def upgrade12(objectList):
-    import filetypes
+    from miro import filetypes
     from datetime import datetime
     changed = set()
     for o in objectList:
@@ -368,7 +367,7 @@ def upgrade27(objectList):
     return set()
 
 def upgrade28(objectList):
-    import filetypes
+    from miro import filetypes
     objectList.sort(key=lambda o:o.savedData['id'])
     changed = set()
     items = set()
@@ -554,7 +553,7 @@ def upgrade40(objectList):
 
 # Turns all strings in data structure to unicode, used by upgrade 41 and 47
 def unicodify(d):
-    from feedparser import FeedParserDict
+    from miro.feedparser import FeedParserDict
     from types import StringType
     if isinstance(d, FeedParserDict):
         for key in d.keys():
@@ -576,7 +575,7 @@ def unicodify(d):
     return d
 
 def upgrade41(objectList):
-    from platformutils import FilenameType
+    from platform.utils import FilenameType
     # This is where John Lennon's ghost sings "Binary Fields Forever"
     if FilenameType == str:
         binaryFields = ['filename','videoFilename', 'shortFilename',
@@ -753,7 +752,7 @@ def upgrade51(objectList):
     return changed
 
 def upgrade52(objectList):
-    import filetypes
+    from miro import filetypes
     changed = set()
     removed = set()
     search_id = 0
@@ -929,6 +928,17 @@ def upgrade61(objectList):
             changed.add(o)
     return changed
 
+def upgrade62(objectList):
+    """Adding baseTitle to feedimpl."""
+    changed = set()
+    for o in objectList:
+        if o.classString == 'feed':
+            o.savedData['baseTitle'] = None
+            changed.add(o)
+    return changed
+
+upgrade63 = upgrade37
+
 #def upgradeX (objectList):
 #    """ upgrade an object list to X.  return set of changed savables. """
 #    changed = set()
