@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2007 Participatory Culture Foundation
+# Copyright (C) 2005-2008 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -66,15 +66,12 @@ Frontend requirements:
     platform (The default button is the 1st button in the list).  Frontends
     should try to recognize standard buttons and display the stock icons for
     them.  
-    """
+"""
 
-import eventloop
-from gtcache import gettext as _
-
-# Pass in a connection to the frontend
-def setDelegate(newDelegate):
-    global delegate
-    delegate = newDelegate
+from miro import app
+from miro import eventloop
+from miro import signals
+from miro.gtcache import gettext as _
 
 class DialogButton(object):
     def __init__(self, text):
@@ -109,6 +106,8 @@ BUTTON_NOT_NOW = DialogButton(_("Not Now"))
 BUTTON_CLOSE_TO_TRAY = DialogButton(_("Close to Tray"))
 BUTTON_LAUNCH_MIRO = DialogButton(_("Launch Miro"))
 BUTTON_DOWNLOAD_ANYWAY = DialogButton(_("Download Anyway"))
+BUTTON_INSTALL_IHEARTMIRO = DialogButton(_("Install iHeartMiro"))
+BUTTON_DONT_INSTALL = DialogButton(_("Don't Install"))
 
 class Dialog(object):
     """Abstract base class for dialogs."""
@@ -121,7 +120,7 @@ class Dialog(object):
     def run(self, callback):
         self.callback = callback
         self.choice = None
-        delegate.runDialog(self)
+        signals.system.newDialog(self)
 
     def runCallback(self, choice):
         """Run the callback for this dialog.  Choice should be the button that
@@ -199,10 +198,10 @@ class SearchChannelDialog(Dialog):
     ENGINE = 1
     URL = 2
     def __init__(self, term=None, style=CHANNEL, location=None):
-        import views
-        import indexes
-        import util
-        from feed import RSSFeedImpl, ScraperFeedImpl
+        from miro import views
+        from miro import indexes
+        from miro import util
+        from miro.feed import RSSFeedImpl, ScraperFeedImpl
         self.term = term
         self.style = style
         self.location = location
@@ -233,9 +232,9 @@ class SearchChannelDialog(Dialog):
                 (BUTTON_CREATE_CHANNEL, BUTTON_CANCEL))
 
     def getURL(self):
-        from xhtmltools import urlencode
-        import searchengines
-        from database import defaultDatabase
+        from miro.xhtmltools import urlencode
+        from miro import searchengines
+        from miro.database import defaultDatabase
 
         term = self.term
         location = self.location
