@@ -1,6 +1,5 @@
 import os
 import sys
-import bsddb
 import shutil
 import types
 from gettext import gettext as _
@@ -10,25 +9,25 @@ from threading import RLock, Event, Thread
 import traceback
 from copy import copy
 
-import libtorrent as lt
-from clock import clock
-from download_utils import cleanFilename, nextFreeFilename, checkFilenameExtension, filterDirectoryName
-from download_utils import filenameFromURL, getFileURLPath
-import eventloop
-import httpclient
+import miro.libtorrent as lt
+from miro.clock import clock
+from miro.download_utils import cleanFilename, nextFreeFilename, checkFilenameExtension, filterDirectoryName
+from miro.download_utils import filenameFromURL, getFileURLPath
+from miro import eventloop
+from miro import httpclient
 import datetime
 import logging
-import fileutil
+from miro import fileutil
 
-import config
-import prefs
+from miro import config
+from miro import prefs
 from sha import sha
 
-from dl_daemon import command, daemon
+from miro.dl_daemon import command, daemon
 from datetime import timedelta
-from util import checkF, checkU, stringify
+from miro.util import checkF, checkU, stringify
+from miro.platform.utils import getAvailableBytesForMovies
 
-import platformutils
 import string
 
 chatter = True
@@ -47,7 +46,7 @@ def createDownloader(url, contentType, dlid):
     if contentType == u'application/x-bittorrent':
         return BTDownloader(url, dlid)
     else:
-        return HTTPDownloader(url, dlid)
+        return HTTPDownloader(url, dlid, expectedContentType=contentType)
 
 # Creates a new downloader object. Returns id on success, None on failure
 def startNewDownload(url, dlid, contentType, channelName):
@@ -339,7 +338,7 @@ class BGDownloader:
         return x.send()
         
     ##
-    def pickInitialFilename(self):
+    def pickInitialFilename(self, suffix=".part"):
         """Pick a path to download to based on self.shortFilename.
 
         This method sets self.filename, as well as creates any leading paths
@@ -353,7 +352,7 @@ class BGDownloader:
             os.makedirs(downloadDir)
         except:
             pass
-        cleaned = cleanFilename(self.shortFilename+".part")
+        cleaned = cleanFilename(self.shortFilename + suffix)
         self.filename = nextFreeFilename(os.path.join(downloadDir, cleaned))
 
     def moveToMoviesDirectory(self):
@@ -467,7 +466,7 @@ class BGDownloader:
             if size < 0:
                 size = 0
             preserved = config.get(prefs.PRESERVE_X_GB_FREE) * 1024 * 1024 * 1024
-            available = platformutils.getAvailableBytesForMovies() - preserved
+            available = getAvailableBytesForMovies() - preserved
             accept = (size <= available)
         return accept
 
@@ -476,9 +475,10 @@ class HTTPDownloader(BGDownloader):
     UPDATE_CLIENT_WINDOW = 12
     HALTED_THRESHOLD = 3 # how many secs until we consider a download halted
 
-    def __init__(self, url = None,dlid = None,restore = None):
+    def __init__(self, url = None, dlid = None, restore = None, expectedContentType = None):
         self.retryDC = None
         self.channelName = None
+        self.expectedContentType = expectedContentType
         if restore is not None:
             if not isinstance(restore.get('totalSize', 0), int):
                 # Sometimes restoring old downloaders caused errors because
@@ -570,7 +570,10 @@ class HTTPDownloader(BGDownloader):
         self.retryCount = -1
         #Get the length of the file, then create it
         self.shortFilename = cleanFilename(info['filename'])
-        self.shortFilename = checkFilenameExtension(self.shortFilename, info)
+        if self.expectedContentType is not None:
+            self.shortFilename = checkFilenameExtension(self.shortFilename, self.expectedContentType)
+        else:
+            self.shortFilename = checkFilenameExtension(self.shortFilename, info.get('content-type'))
         self.pickInitialFilename()
         try:
             self.filehandle = file(self.filename,"w+b")
@@ -772,9 +775,8 @@ class BTDownloader(BGDownloader):
                                  (self.totalSize / (2 ** 20)))
                 return
 
-            name = stringify(self.filename)
+            name = os.path.dirname(stringify(self.filename))
             if self.fastResumeData:
-                resume = lt.bdecode(self.fastResumeData)
                 self.torrent = torrentSession.session.add_torrent(torrent_info, name, lt.bdecode(self.fastResumeData), lt.storage_mode_t.storage_mode_allocate)
             else:
                 self.torrent = torrentSession.session.add_torrent(torrent_info, name, None, lt.storage_mode_t.storage_mode_allocate)
@@ -856,6 +858,11 @@ class BTDownloader(BGDownloader):
         else:
             downloadUpdater.queueUpdate(self)
 
+        if config.get(prefs.LIMIT_UPLOAD_RATIO):
+            if status.state == lt.torrent_status.states.seeding:
+                if float(self.uploaded)/self.totalSize > config.get(prefs.UPLOAD_RATIO):
+                    self.stopUpload()
+
     def handleError(self, shortReason, reason):
         self._shutdownTorrent()
         BGDownloader.handleError(self, shortReason, reason)
@@ -902,6 +909,7 @@ class BTDownloader(BGDownloader):
         
     def pause(self):
         self.state = "paused"
+        self.restarting = True
         self._pauseTorrent()
         self.updateClient()
 
@@ -952,7 +960,7 @@ class BTDownloader(BGDownloader):
                 return
             name = name.decode('utf-8', 'replace')
             self.shortFilename = cleanFilename(name)
-            self.pickInitialFilename()
+            self.pickInitialFilename("")
         self.updateClient()
         self._resumeTorrent()
 
