@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2007 Participatory Culture Foundation
+# Copyright (C) 2005-2008 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,50 +26,49 @@
 # this exception statement from your version. If you delete this exception
 # statement from all source files in the program, then also delete it here.
 
-# FIXME import * is really bad practice..  At the very least, lest keep it at
-# the top, so it cant overwrite other symbols.
-from item import *
 
 from HTMLParser import HTMLParser,HTMLParseError
 from cStringIO import StringIO
 from copy import copy
 from datetime import datetime, timedelta
-from gtcache import gettext as _
+from miro.gtcache import gettext as _
+from miro.feedparser import FeedParserDict
 from inspect import isfunction
 from new import instancemethod
 from urlparse import urlparse, urljoin
-from xhtmltools import unescape,xhtmlify,fixXMLHeader, fixHTMLHeader, urlencode, urldecode
+from miro.xhtmltools import unescape,xhtmlify,fixXMLHeader, fixHTMLHeader, urlencode, urldecode
 import os
 import string
 import re
 import traceback
 import xml
 
-from database import defaultDatabase, DatabaseConstraintError
-from httpclient import grabURL, NetworkError
-from iconcache import iconCacheUpdater, IconCache
-from templatehelper import quoteattr, escape, toUni
+from miro.database import defaultDatabase, DatabaseConstraintError, DDBObject
+from miro.databasehelper import makeSimpleGetSet
+from miro.httpclient import grabURL, NetworkError
 from string import Template
-import app
-import config
-import dialogs
-import eventloop
-import folder
-import menu
-import prefs
-import resources
-import downloader
-from util import returnsUnicode, unicodify, chatter, checkU, checkF, quoteUnicodeURL
-from fileutil import miro_listdir
-from platformutils import filenameToUnicode, makeURLSafe, unmakeURLSafe, osFilenameToFilenameType, FilenameType
-import filetypes
-import views
-import indexes
-import searchengines
-import sorts
+from miro import app
+from miro import config
+from miro import iconcache
+from miro import dialogs
+from miro import eventloop
+from miro import filters
+from miro import folder
+from miro import prefs
+from miro.platform import resources
+from miro import downloader
+from miro.util import (returnsUnicode, unicodify, chatter, checkU, checkF, quoteUnicodeURL, getFirstVideoEnclosure, escape, toUni)
+from miro.fileutil import miro_listdir, miro_allfiles
+from miro.platform.utils import filenameToUnicode, makeURLSafe, unmakeURLSafe, osFilenameToFilenameType, FilenameType
+from miro import filetypes
+from miro import item as itemmod
+from miro import views
+from miro import indexes
+from miro import searchengines
+from miro import sorts
 import logging
 import shutil
-from clock import clock
+from miro.clock import clock
 
 whitespacePattern = re.compile(r"^[ \t\r\n]*$")
 
@@ -96,17 +95,7 @@ def defaultFeedIconURLTablist():
 
 # Universal Feed Parser http://feedparser.org/
 # Licensed under Python license
-import feedparser
-
-# Pass in a connection to the frontend
-def setDelegate(newDelegate):
-    global delegate
-    delegate = newDelegate
-
-# Pass in a feed sorting function 
-def setSortFunc(newFunc):
-    global sortFunc
-    sortFunc = newFunc
+from miro import feedparser
 
 #
 # Adds a new feed using USM
@@ -220,10 +209,7 @@ class FeedImpl:
         self.url = url
         self.ufeed = ufeed
         self.calc_item_list()
-        if title == None:
-            self.title = url
-        else:
-            self.title = title
+        self.title = title
         self.created = datetime.now()
         self.visible = visible
         self.updating = False
@@ -489,8 +475,11 @@ class FeedImpl:
     def getTitle(self):
         try:
             title = self.title
-            if whitespacePattern.match(title):
-                title = self.url
+            if title is None or whitespacePattern.match(title):
+                if self.ufeed.baseTitle is not None:
+                    title = self.ufeed.baseTitle
+                else:
+                    title = self.url
             return title
         except:
             return u""
@@ -588,23 +577,42 @@ class Feed(DDBObject):
     ICON_CACHE_SIZES = [
         (20, 20),
         (76, 76),
-    ] + Item.ICON_CACHE_SIZES
+    ]
 
-    def __init__(self,url, initiallyAutoDownloadable=True):
+    def __init__(self,url, initiallyAutoDownloadable=None):
         DDBObject.__init__(self, add=False)
         checkU(url)
-        self.autoDownloadable = initiallyAutoDownloadable
-        self.getEverything = False
+        if initiallyAutoDownloadable == None:
+            mode = config.get(prefs.CHANNEL_AUTO_DEFAULT)
+            # note that this is somewhat duplicated in setAutoDownloadMode
+            logging.info ("wbg: setting autodownload stuff initially to %s" % mode)
+            if mode == u'all':
+                self.getEverything = True
+                self.autoDownloadable = True
+            elif mode == u'new':
+                self.getEverything = False
+                self.autoDownloadable = True
+            elif mode == u'off':
+                self.getEverything = False
+                self.autoDownloadable = False
+            else:
+                raise ValueError("Bad auto-download mode: %s" % mode)
+    
+        else:
+            self.autoDownloadable = initiallyAutoDownloadable
+            self.getEverything = False
+
         self.maxNew = 3
         self.expire = u"system"
         self.expireTime = None
         self.fallBehind = -1
 
+        self.baseTitle = None
         self.origURL = url
         self.errorState = False
         self.loading = True
         self.actualFeed = FeedImpl(url,self)
-        self.iconCache = IconCache(self, is_vital = True)
+        self.iconCache = iconcache.IconCache(self, is_vital = True)
         self.informOnError = True
         self.folder_id = None
         self.searchTerm = None
@@ -674,13 +682,13 @@ class Feed(DDBObject):
 
     @returnsUnicode
     def getTitle(self):
-        if self.userTitle is None:
+        if self.userTitle is not None:
+            return self.userTitle
+        else:
             title = self.actualFeed.getTitle()
             if self.searchTerm is not None:
                 title = u"'%s' on %s" % (self.searchTerm, title)
             return title
-        else:
-            return self.userTitle
 
     def setTitle(self, title):
         self.confirmDBThread()
@@ -690,6 +698,13 @@ class Feed(DDBObject):
     def unsetTitle(self):
         self.setTitle(None)
 
+    ##
+    # Set the baseTitle.
+    @returnsUnicode
+    def setBaseTitle(self, title):
+        self.baseTitle = title
+        self.signalChange()
+
     @returnsUnicode
     def getAutoDownloadMode(self):
         self.confirmDBThread()
@@ -702,6 +717,7 @@ class Feed(DDBObject):
             return u'off'
 
     def setAutoDownloadMode(self, mode):
+        # note that this is somewhat duplicated in __init__
         if mode == u'all':
             self.setGetEverything(True)
             self.setAutoDownloadable(True)
@@ -802,22 +818,9 @@ class Feed(DDBObject):
 #        for item in self.items:
 #            item.signalChange(needsSave=False)
         if self.maxNew >= oldMaxNew or self.maxNew < 0:
-            import autodler
+            from miro import autodler
             autodler.autoDownloader.startDownloads()
 
-    def makeContextMenu(self, templateName, view):
-        items = [
-            (self.update, _('Update Channel Now')),
-            (lambda: app.delegate.copyTextToClipboard(self.getURL()),
-                _('Copy URL to clipboard')),
-            (self.rename, _('Rename Channel')),
-        ]
-
-        if self.userTitle:
-            items.append((self.unsetTitle, _('Revert Title to Default')))
-        items.append((lambda: app.controller.removeFeed(self), _('Remove')))
-        return menu.makeMenu(items)
-
     def rename(self):
         title = _("Rename Channel")
         text = _("Enter a new name for the channel %s" % self.getTitle())
@@ -952,6 +955,12 @@ class Feed(DDBObject):
 
         if not self.idExists():
             return
+        if info['updated-url'] != self.origURL and \
+                not self.origURL.startswith('dtv:'): # we got redirected
+            f = getFeedByURL(info['updated-url'])
+            if f is not None: # already have this feed, so delete us
+                self.remove()
+                return
         self.download = None
         modified = unicodify(info.get('last-modified'))
         etag = unicodify(info.get('etag'))
@@ -1145,7 +1154,7 @@ $shortAppName.\n\nDo you want to try to load this channel anyway?"""))
         return False
 
     def updateIcons(self):
-        iconCacheUpdater.clearVital()
+        iconcache.iconCacheUpdater.clearVital()
         for item in self.items:
             item.iconCache.requestUpdate(True)
         for feed in views.feeds:
@@ -1161,7 +1170,7 @@ $shortAppName.\n\nDo you want to try to load this channel anyway?"""))
 
     def onRestore(self):
         if (self.iconCache == None):
-            self.iconCache = IconCache (self, is_vital = True)
+            self.iconCache = iconcache.IconCache (self, is_vital = True)
         else:
             self.iconCache.dbItem = self
             self.iconCache.requestUpdate(True)
@@ -1360,7 +1369,7 @@ class RSSFeedImpl(FeedImpl):
 
     def _handleNewEntry(self, entry, channelTitle):
         """Handle getting a new entry from a feed."""
-        item = Item(entry, feed_id=self.ufeed.id)
+        item = itemmod.Item(entry, feed_id=self.ufeed.id)
         if not filters.matchingItems(item, self.ufeed.searchTerm):
             item.remove()
         item.setChannelTitle(channelTitle)
@@ -1723,7 +1732,7 @@ class RSSMultiFeedImpl(FeedImpl):
 
     def _handleNewEntry(self, entry, channelTitle):
         """Handle getting a new entry from a feed."""
-        item = Item(entry, feed_id=self.ufeed.id)
+        item = itemmod.Item(entry, feed_id=self.ufeed.id)
         if not filters.matchingItems(item, self.ufeed.searchTerm):
             item.remove()
         item.setChannelTitle(channelTitle)
@@ -1895,7 +1904,7 @@ class Collection(FeedImpl):
     ##
     # Adds an item to the collection
     def addItem(self,item):
-        if isinstance(item,Item):
+        if isinstance(item, itemmod.Item):
             self.ufeed.confirmDBThread()
             self.removeItem(item)
             self.items.append(item)
@@ -2026,9 +2035,9 @@ class ScraperFeedImpl(FeedImpl):
         # Anywhere we call this, we need to convert the input back to unicode
         title = feedparser.sanitizeHTML (title, "utf-8").decode('utf-8')
         if dict.has_key('thumbnail') > 0:
-            i=Item(FeedParserDict({'title':title,'enclosures':[FeedParserDict({'url':link,'thumbnail':FeedParserDict({'url':dict['thumbnail']})})]}),linkNumber = linkNumber, feed_id=self.ufeed.id)
+            i=itemmod.Item(FeedParserDict({'title':title,'enclosures':[FeedParserDict({'url':link,'thumbnail':FeedParserDict({'url':dict['thumbnail']})})]}),linkNumber = linkNumber, feed_id=self.ufeed.id)
         else:
-            i=Item(FeedParserDict({'title':title,'enclosures':[FeedParserDict({'url':link})]}),linkNumber = linkNumber, feed_id=self.ufeed.id)
+            i=itemmod.Item(FeedParserDict({'title':title,'enclosures':[FeedParserDict({'url':link})]}),linkNumber = linkNumber, feed_id=self.ufeed.id)
         if self.ufeed.searchTerm is not None and not filters.matchingItems(i, self.ufeed.searchTerm):
             i.remove()
             return
@@ -2260,8 +2269,8 @@ class DirectoryWatchFeedImpl(FeedImpl):
                 for subfile in subfiles:
                     all_files.append(subfile)
             for file in all_files:
-                if file not in knownFiles and filetypes.isVideoFilename(platformutils.filenameToUnicode(file)):
-                    FileItem(file, feed_id=self.ufeed.id)
+                if file not in knownFiles and filetypes.isVideoFilename(filenameToUnicode(file)):
+                    itemmod.FileItem(file, feed_id=self.ufeed.id)
 
         for item in self.items:
             if not os.path.isfile(item.getFilename()):
@@ -2329,42 +2338,10 @@ class DirectoryFeedImpl(FeedImpl):
         #Adds any files we don't know about
         #Files on the filesystem
         if os.path.isdir(moviesDir):
-            files, dirs = miro_listdir(moviesDir)
-            for file in files:
-                if not file in knownFiles:
-                    FileItem(file, feed_id=self.ufeed.id)
-            for dir in dirs:
-                if dir in knownFiles:
-                    continue
-                found = 0
-                not_found = []
-                subfiles, subdirs = miro_listdir(dir)
-                for subfile in subfiles:
-                    if subfile in knownFiles:
-                        found = found + 1
-                    else:
-                        not_found.append(subfile)
-                for subdir in subdirs:
-                    if subdir in knownFiles:
-                        found = found + 1
-                # If every subfile or subdirectory is
-                # already in the database (including
-                # the case where the directory is
-                # empty) do nothing.
-                if len(not_found) > 0:
-                    # If there were any files found,
-                    # this is probably a channel
-                    # directory that someone added
-                    # some thing to.  There are few
-                    # other cases where a directory
-                    # would have some things shown.
-                    if found != 0:
-                        for subfile in not_found:
-                            FileItem(subfile, feed_id=self.ufeed.id)
-                    # But if not, it's probably a
-                    # directory added wholesale.
-                    else:
-                        FileItem(dir, feed_id=self.ufeed.id)
+            all_files = miro_allfiles(moviesDir)
+            for file in all_files:
+                if file not in knownFiles and filetypes.isVideoFilename(filenameToUnicode(file)):
+                    itemmod.FileItem(file, feed_id=self.ufeed.id)
 
         for item in self.items:
             if not os.path.exists(item.getFilename()):
