@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2007 Participatory Culture Foundation
+# Copyright (C) 2005-2008 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,9 +30,9 @@
 
 import gettext as _gt
 import locale
-import config
-import prefs
-import platformutils
+from miro import config
+from miro import prefs
+import miro.platform.utils
 import os
 
 _gtcache = None
@@ -40,9 +40,17 @@ _gtcache = None
 def init():
     global _gtcache
     _gtcache = {}
-    if not platformutils.localeInitialized:
+    if not miro.platform.utils.localeInitialized:
         raise Exception, "locale not initialized"
-    locale.setlocale(locale.LC_ALL, '')
+
+    # try to set the locale to the platform default, but if that fails
+    # log a message and set it to C.
+    try:
+        locale.setlocale(locale.LC_ALL, '')
+    except locale.Error, e:
+        import logging
+	logging.warn("gtcache.init: setlocale failed.  setting locale to 'C'")
+        locale.setlocale(locale.LC_ALL, 'C')
 
     _gt.bindtextdomain("miro", config.get(prefs.GETTEXT_PATHNAME))
     _gt.textdomain("miro")
