@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2007 Participatory Culture Foundation
+# Copyright (C) 2005-2008 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,25 +26,24 @@
 # this exception statement from your version. If you delete this exception
 # statement from all source files in the program, then also delete it here.
 
-import item
 import os
 import threading
-import httpclient
+from miro import httpclient
 from fasttypes import LinkedList
-from eventloop import asIdle, addIdle, addTimeout
-from download_utils import nextFreeFilename, getFileURLPath
-from util import unicodify, call_command
-from platformutils import unicodeToFilename
-import config
-import prefs
+from miro.eventloop import asIdle, addIdle, addTimeout
+from miro.download_utils import nextFreeFilename, getFileURLPath
+from miro.util import unicodify, call_command
+from miro.platform.utils import unicodeToFilename
+from miro import config
+from miro import prefs
 import time
-import views
 import random
-import imageresize
+from miro import imageresize
 
 RUNNING_MAX = 3
     
 def clearOrphans():
+    from miro import views
     knownIcons = set()
     for item in views.items:
         if item.iconCache and item.iconCache.filename:
