@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2007 Participatory Culture Foundation
+# Copyright (C) 2005-2008 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -47,12 +47,12 @@ import threading
 import types
 import time
 
-from schema import ObjectSchema, SchemaInt, SchemaFloat, SchemaSimpleItem
-from schema import SchemaObject, SchemaBool, SchemaDateTime, SchemaTimeDelta
-from schema import SchemaList, SchemaDict
+from miro.schema import ObjectSchema, SchemaInt, SchemaFloat, SchemaSimpleItem
+from miro.schema import SchemaObject, SchemaBool, SchemaDateTime, SchemaTimeDelta
+from miro.schema import SchemaList, SchemaDict
 from fasttypes import LinkedList
 from types import NoneType
-import storedatabase
+from miro import storedatabase
 
 ######################### STAGE 1 helpers  #############################
 # Below is a snapshot of what the database looked like at 0.8.2.  DDBObject
@@ -78,8 +78,9 @@ import storedatabase
 # version 6 we avoid that bug, while still giving the people using version 1
 # and 2 an upgrade path that does something.
 
+
 def defaultFeedIconURL():
-    import resources
+    from miro.platform import resources
     return resources.url("images/feedicon.png")
 
 #Dummy class for removing bogus FileItem instances
@@ -313,11 +314,15 @@ class FakeClassUnpickler(pickle.Unpickler):
         'datetime.datetime', 
         'datetime.timedelta', 
         'time.struct_time',
-        'feedparser.FeedParserDict',
+        'miro.feedparser.FeedParserDict',
         '__builtin__.unicode',
     ]
 
     def find_class(self, module, name):
+        if module == 'feedparser':
+            # hack to handle the fact that everything is inside the miro
+            # package nowadays
+            module = 'miro.feedparser'
         fullyQualifiedName = "%s.%s" % (module, name)
         if fullyQualifiedName in fakeClasses:
             return fakeClasses[fullyQualifiedName]
