@@ -1,8 +1,8 @@
 import unittest
-import feedparser
-import resources
+from miro import feedparser
+from miro.platform import resources
 
-from test.framework import DemocracyTestCase
+from miro.test.framework import DemocracyTestCase
 
 class FeedParserDictTest(DemocracyTestCase):
     def test(self):
