@@ -1,21 +1,24 @@
 import unittest
 import email.Utils
 import socket
+import sys
 import tempfile
 import traceback
 from copy import copy
 from StringIO import StringIO
 
-from clock import clock
+from miro.clock import clock
 import os
 
-from download_utils import cleanFilename
-import download_utils
-import database
-import dialogs
-import httpclient
-import util
-from framework import EventLoopTest, DemocracyTestCase, HadToStopEventLoop
+from miro.download_utils import cleanFilename
+from miro import app
+from miro import download_utils
+from miro import database
+from miro import dialogs
+from miro import httpclient
+from miro import signals
+from miro import util
+from miro.test.framework import EventLoopTest, DemocracyTestCase, HadToStopEventLoop
 
 class TestingConnectionHandler(httpclient.ConnectionHandler):
     def __init__(self, test):
@@ -283,19 +286,6 @@ class TestHTTPClient(httpclient.HTTPClient):
 class TestingHeaderGrabber(httpclient.HTTPHeaderGrabber):
     connectionPool = TestingHTTPConnectionPool()
 
-class TestingAuthDelegate:
-    def __init__(self):
-        self.logins = []
-    def addLogin(self, user, password):
-        self.logins.append((user, password))
-
-    def runDialog(self, dialog):
-        if self.logins:
-            user, password = self.logins.pop(0)
-            dialog.runCallback(dialogs.BUTTON_OK, user, password)
-        else:
-            dialog.runCallback(None)
-
 def startResponse(version='1.1', status=200, headers={}):
     rv = """\
 HTTP/%s %s OK\r
@@ -331,6 +321,7 @@ class AsyncSocketTest(EventLoopTest):
 class NetworkBufferTest(DemocracyTestCase):
     def setUp(self):
         self.buffer = httpclient.NetworkBuffer()
+        DemocracyTestCase.setUp(self)
 
 #    def testMemory(self):
 #        i = 0
@@ -507,12 +498,6 @@ class DumbHTTPClientTest(AsyncSocketTest):
         self.testRequest.openConnection('foo.com', 80, lambda x: None,lambda x: None)
         self.testRequest.sendRequest(self.callback, self.errback, "", 80,
                 method='GET', path='/bar/baz;123?a=b') 
-        self.authDelegate = TestingAuthDelegate()
-        dialogs.setDelegate(self.authDelegate)
-
-    def tearDown(self):
-        # clear out any HTTPAuth objects in there
-        AsyncSocketTest.tearDown(self)
 
     def testScheme(self):
         conn = httpclient.HTTPConnection()
@@ -589,18 +574,11 @@ HELLO: WORLD\r\n"""
             'text/plain; charset=ISO-8859-1')
 
     def testCallbackError(self):
+        self.errorSignalOkay = True
         self.fakeCallbackError = True
-        self.failedCalled = False
-        def fakeFailed(*args, **kwargs):
-            self.failedCalled = True
-        oldFailed = util.failed
-        util.failed = fakeFailed
-        try:
-            self.testRequest.handleData(self.fakeResponse)
-            self.testRequest.handleClose(socket.SHUT_RD)
-        finally:
-            util.failed = oldFailed
-        self.assert_(self.failedCalled)
+        self.testRequest.handleData(self.fakeResponse)
+        self.testRequest.handleClose(socket.SHUT_RD)
+        self.assert_(self.sawError)
 
     def testHeaderContinuation(self):
         self.testRequest.handleData("HTTP/1.0 200 OK\r\n")
@@ -808,15 +786,21 @@ class HTTPClientTestBase(AsyncSocketTest):
         self.testRequest = TestingHTTPConnection()
         self.testRequest.openConnection('foo.com', 80, lambda x: None, lambda x: None)
         self.testRequest.sendRequest(self.callback, self.errback, "", 80, method='GET', path='/bar/baz;123?a=b') 
-        self.authDelegate = TestingAuthDelegate()
-        dialogs.setDelegate(self.authDelegate)
         TestHTTPClient.connectionPool = TestingHTTPConnectionPool()
         TestingHeaderGrabber.connectionPool = TestingHTTPConnectionPool()
+        self.logins = []
+        signals.system.connect('new-dialog', self.onNewDialog)
 
-    def tearDown(self):
-        # clear out any HTTPAuth objects in there
-        AsyncSocketTest.tearDown(self)
+    def addLogin(self, user, password):
+        self.logins.append((user, password))
 
+    def onNewDialog(self, obj, dialog):
+        self.assertEquals(dialog.__class__, dialogs.HTTPAuthDialog)
+        if self.logins:
+            user, password = self.logins.pop(0)
+            dialog.runCallback(dialogs.BUTTON_OK, user, password)
+        else:
+            dialog.runCallback(None)
 
 class HTTPClientTest(HTTPClientTestBase):
     def testRealRequest(self):
@@ -930,16 +914,11 @@ class HTTPClientTest(HTTPClientTestBase):
         url = 'http://participatoryculture.org/democracytest/normalpage.txt'
         reqId = httpclient.grabURL(url, self.callback, self.errback,
                 headerCallback=headerCallback, clientClass=TestHTTPClient)
-        self.failedCalled = False
-        def fakeFailed(*args, **kwargs):
-            self.failedCalled = True
-        oldFailed = util.failed
-        util.failed = fakeFailed
+        self.errorSignalOkay = True
         self.runEventLoop()
-        util.failed = oldFailed
         self.assert_(not self.callbackCalled)
         self.assert_(not self.errbackCalled)
-        self.assert_(not self.failedCalled)
+        self.assert_(not self.sawError)
 
     def testBodyDataCallbackCancel(self):
         def bodyDataCallback(response):
@@ -948,16 +927,11 @@ class HTTPClientTest(HTTPClientTestBase):
         url = 'http://participatoryculture.org/democracytest/normalpage.txt'
         reqId = httpclient.grabURL(url, self.callback, self.errback,
                 bodyDataCallback=bodyDataCallback, clientClass=TestHTTPClient)
-        self.failedCalled = False
-        def fakeFailed(*args, **kwargs):
-            self.failedCalled = True
-        oldFailed = util.failed
-        util.failed = fakeFailed
+        self.errorSignalOkay = True
         self.runEventLoop()
-        util.failed = oldFailed
         self.assert_(not self.callbackCalled)
         self.assert_(not self.errbackCalled)
-        self.assert_(not self.failedCalled)
+        self.assert_(not self.sawError)
 
     def testBodyDataCallback(self):
         self.lastSeen = None
@@ -1007,8 +981,8 @@ class HTTPClientTest(HTTPClientTestBase):
         self.assertEquals(self.gotData, 'I AM A NORMAL PAGE\n')
 
     def testAuth(self):
-        self.authDelegate.addLogin(u'ben', u'baddpassword')
-        self.authDelegate.addLogin(u'guest', u'guest')
+        self.addLogin(u'ben', u'baddpassword')
+        self.addLogin(u'guest', u'guest')
         url = 'http://jigsaw.w3.org/HTTP/Basic/'
         client = TestHTTPClient(url, self.callback, self.errback)
         client.startRequest()
@@ -1018,9 +992,9 @@ class HTTPClientTest(HTTPClientTestBase):
         self.assertEquals(client.authAttempts, 2)
 
     def testBadAuth(self):
-        self.authDelegate.addLogin(u'baduser', u'baddpass')
-        self.authDelegate.addLogin(u'anotherbadtry', u'god')
-        self.authDelegate.addLogin(u'billgates', u'password')
+        self.addLogin(u'baduser', u'baddpass')
+        self.addLogin(u'anotherbadtry', u'god')
+        self.addLogin(u'billgates', u'password')
         url = 'http://jigsaw.w3.org/HTTP/Basic/'
         client = TestHTTPClient(url, self.callback, self.errback)
         client.startRequest()
@@ -1182,7 +1156,10 @@ class HTTPClientTest(HTTPClientTestBase):
         client = TestHTTPClient('http://www.foo.com', self.callback, self.errback)
 
         def getIt(path, cd=None):
-            response = {'path': path}
+            response = {
+                    'path': path, 
+                    'redirected-url': 'http://example.com' + path
+            }
             if cd:
                 response['content-disposition'] = cd
             return client.getFilenameFromResponse(response)
@@ -1625,7 +1602,7 @@ class CookieExpirationDateTestCase(unittest.TestCase):
         problems with.
         """
         from time import mktime, strptime, localtime
-        from httpclient import get_cookie_expiration_date
+        from miro.httpclient import get_cookie_expiration_date
         
         for cd in ( ("Thu, 03-May-07 22:48:52 GMT", "2007-05-03 22:48:52 GMT" ),
                     ("Fri, 03-Jun-11 13:41:15 GMT", "2011-06-03 13:41:15 GMT" ),
@@ -1643,8 +1620,11 @@ class CookieExpirationDateTestCase(unittest.TestCase):
         """tests the case of get_cookie_expiration_date where the cookie
         expiration date causes an overflow error when parsing it.
         """
+        if sys.maxint > 2**31-1:
+            # this test can't be executed on 64 bit systems
+            return
         from time import localtime
-        from httpclient import get_cookie_expiration_date, DATEINFUTURE
+        from miro.httpclient import get_cookie_expiration_date, DATEINFUTURE
             
         self.assertEquals( localtime(get_cookie_expiration_date("Tue, 26-Jul-2050 10:00:00 GMT")),
                            localtime(httpclient.DATEINFUTURE) )
