@@ -4,12 +4,12 @@ import tempfile
 import time
 import unittest
 
-import schema
+from miro import schema
 # much easier to type this way..
-from schema import SchemaString, SchemaInt, SchemaFloat, SchemaBool
-from schema import SchemaDateTime, SchemaList, SchemaDict, SchemaObject
-from schema import SchemaSimpleContainer, ValidationError
-from test.framework import DemocracyTestCase
+from miro.schema import SchemaString, SchemaInt, SchemaFloat, SchemaBool
+from miro.schema import SchemaDateTime, SchemaList, SchemaDict, SchemaObject
+from miro.schema import SchemaSimpleContainer, ValidationError
+from miro.test.framework import DemocracyTestCase
 
 class TestValidation(DemocracyTestCase):
     def testModuleVariablesDefined(self):
